@@ -78,8 +78,8 @@ class sslsocket(object):
                 self._fillbuf()
             log.trace('checking self.buf\n')
             if self.buf:
-                log.trace('self.buf = "%r", len %i\n'
-                          % (self.buf, len(self.buf)))
+                log.trace('self.buf = "%r", len %i\n' 
+                    % (self.buf, len(self.buf)))
                 while True:
                     log.trace('looking for EOL\n')
                     i = self.buf.find('\n')
@@ -101,8 +101,7 @@ class sslsocket(object):
             return line
         except (socket.sslerror, socket.error), o:
             raise getmailOperationError(
-                'socket/ssl error while reading from server (%s)' % o
-            )
+                'socket/ssl error while reading from server (%s)' % o)
 
 class POP3SSL(POP3):
     '''Thin subclass to add SSL functionality to the built-in POP3 class.
@@ -120,9 +119,8 @@ class POP3SSL(POP3):
         msg = "getaddrinfo returns an empty list"
         self.rawsock = None
         self.sock = None
-        for res in socket.getaddrinfo(self.host, self.port, 0,
-                                      socket.SOCK_STREAM):
-            (af, socktype, proto, canonname, sa) = res
+        for res in socket.getaddrinfo(self.host, self.port, 0, socket.SOCK_STREAM):
+            af, socktype, proto, canonname, sa = res
             try:
                 self.rawsock = socket.socket(af, socktype, proto)
                 self.rawsock.connect(sa)
@@ -146,10 +144,8 @@ class POP3SSL(POP3):
     # Raise error_proto('-ERR EOF') if the connection is closed.
     def _getline(self):
         line = self.sock.readline()
-        if self._debugging > 1:
-            print '*get*', `line`
-        if not line:
-            raise error_proto('-ERR EOF')
+        if self._debugging > 1: print '*get*', `line`
+        if not line: raise error_proto('-ERR EOF')
         octets = len(line)
         # server can send any combination of CR & LF
         # however, 'readline()' returns lines ending in LF
@@ -161,8 +157,7 @@ class POP3SSL(POP3):
         return line[:-1], octets
 
     def quit(self):
-        """Signoff: commit changes on server, unlock mailbox, close connection.
-        """
+        """Signoff: commit changes on server, unlock mailbox, close connection."""
         try:
             resp = self._shortcmd('QUIT')
         except (error_proto, socket.error), val:
